#
# spec file for package ghc-ansi-terminal
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name ansi-terminal
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        1.1.2
Release:        1.3
Summary:        Simple ANSI terminal support
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-ansi-terminal-types-devel
BuildRequires:  ghc-ansi-terminal-types-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-colour-devel
BuildRequires:  ghc-colour-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}

%description
ANSI terminal support for Haskell: allows cursor movement, screen clearing,
color output, showing or hiding the cursor, and changing the title.
Works on UNIX and Windows.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Nov 14 2024 Peter Simons <psimons@suse.com>
- Update ansi-terminal to version 1.1.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/ansi-terminal-1.1.2/src/CHANGELOG.md
* Sat Jan 13 2024 Peter Simons <psimons@suse.com>
- Update ansi-terminal to version 1.0.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/ansi-terminal-1.0.2/src/CHANGELOG.md
* Sat May 13 2023 Peter Simons <psimons@suse.com>
- Update ansi-terminal to version 1.0.
  Version 1.0
  - ----------
  * On Windows, drop support for legacy Windows requiring emulation.
  * On Windows, the package no longer depends (directly or indirectly) on the
    `Win32`, `array`,`containers`, `deepseq`, `filepath`, `ghc-boot-th`, `mintty`,
    `pretty` or `template-haskell` packages.
  * `hSupportsANSI` no longer assumes that the given handle is writeable.
  * `hSupportsANSIWithoutEmulation` is deprecated.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Mar 20 2023 Peter Simons <psimons@suse.com>
- Update ansi-terminal to version 0.11.5.
  Version 0.11.5
  - -------------
  * Module `System.Console.ANSI.Types` spun out to new dependency package
    `ansi-terminal-types-0.11.5`.
  * Drop support for GHC versions before GHC 7.10.1 (released March 2015).
  * Improvements to Haddock documentation.
* Mon Nov 21 2022 Peter Simons <psimons@suse.com>
- Update ansi-terminal to version 0.11.4.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/ansi-terminal-0.11.4/src/CHANGELOG.md
* Thu Apr 28 2022 Peter Simons <psimons@suse.com>
- Update ansi-terminal to version 0.11.3.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/ansi-terminal-0.11.3/src/CHANGELOG.md
* Tue Nov 23 2021 Peter Simons <psimons@suse.com>
- Update ansi-terminal to version 0.11.1.
  Version 0.11.1
  - -------------
  * On Windows, fix compatability with the Windows I/O Manager (WinIO) introduced
    in GHC 9.0.1, by incorporating changes made in package `Win32-2.13.2.0` in
    that regard.
  * Improvements to Haddock documentation.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Aug 11 2020 psimons@suse.com
- Update ansi-terminal to version 0.11.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/ansi-terminal-0.11/src/CHANGELOG.md
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Thu Feb 27 2020 psimons@suse.com
- Update ansi-terminal to version 0.10.3.
  Version 0.10.3
  - -------------
  * Add `getCursorPosition` as a synonym of `getCursorPosition0` and deprecate the
    latter.
* Thu Nov 21 2019 psimons@suse.com
- Update ansi-terminal to version 0.10.2.
  Version 0.10.2
  - -------------
  * `hGetTerminalSize` now assumes a terminal is no bigger than 9,999 by 9,999
    (previously, no bigger than 999 by 999).
  * On Windows, fix a bug where emulated cursor movement functions differed from
    Windows 10 (movement bounded by the current viewport).
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sun Oct  6 2019 psimons@suse.com
- Update ansi-terminal to version 0.10.1.
  Version 0.10.1
  - -------------
  * Add `hGetCursorPosition` and `hGetTerminalSize`.
  * On Unix-like operating systems, fix a bug where `getReportedCursorPosition`
    could block indefinitely if no information was forthcoming on the console
    input stream.
  * Improvements to Haddock documentation.
* Fri Sep  6 2019 psimons@suse.com
- Update ansi-terminal to version 0.10.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/ansi-terminal-0.10/src/CHANGELOG.md
* Mon May 13 2019 psimons@suse.com
- Update ansi-terminal to version 0.9.1.
  Version 0.9.1
  - ------------
  * Flag modules with GHC's 'Safe Haskell' language extensions (from GHC 7.2.1).
  * Improvements and corrections to Haddock documentation.
* Sun Jan 27 2019 psimons@suse.com
- Update ansi-terminal to version 0.9.
  Version 0.9
  - ----------
  * Add support for 256-color palettes with new `SetPaletteColor` constructor of
    `SGR` type, and `xterm6LevelRGB`, `xterm24LevelGray` and `xtermSystem`.
  * Remove deprecated `getCursorPosition`. (Use `getCursorPosition0` instead.)
  * Add `hSupportsANSIColor`.
  * Add `getTerminalSize`.
  * Improvements to Haddock documentation.
* Mon Oct 29 2018 psimons@suse.com
- Update ansi-terminal to version 0.8.2.
  Version 0.8.2
  - ------------
  * Add `getCursorPosition0` and deprecate `getCursorPosition`. Any position
    provided by the latter is 1-based. Any position provided by the former is
    0-based, consistent with `setCursorColumn` and `setCursorPosition`.
  * Improvements to Haddock documentation in respect of 0-based and 1-based
    cursor positions.
* Thu Oct  4 2018 psimons@suse.com
- Update ansi-terminal to version 0.8.1.
  * Add `hSupportsANSIWithoutEmulation`. On Windows 10, if the handle is identifed
    as connected to a native terminal ('Command Prompt' or 'PowerShell'), the
    processing of 'ANSI' control characters will be enabled.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update ansi-terminal to version 0.8.0.4.
  * On Windows, `hSupportsANSI` now recognises if the handle is connected to a
    'mintty' terminal.
  * On Windows, try to enable ANSI on ConHost terminals even if a TERM environment
    variable exits (such as with the Hyper 2 terminal)
  * Minor improvements to Haddock documentation
  * Improve README and Haddock documentation
  * On Windows, fix compatability with earlier GHC versions
  * Drop support for GHC versions before 6.12.1 (released December 2009)
  * On Windows, if the standard output channel is valid but not a ConHost
    terminal, assume it is ANSI-enabled rather than failing
  * On Windows, output the improved error message to the standard error channel
    rather than the standard output channel
  * Make the fields of `SGR` strict
  * Make compatible with GHC 8.2.2
  * Improve the error message on Windows when not ANSI-capable or ConHost
  * Recognise Appveyor build environment as ANSI-enabled
    `getReportedCursorPosition`: don't let the cursor reporting code be echo'd
  * Allow saving, restoring, and querying the current cursor position
  * Fix a couple of issues with the Reset emulation on Windows
  * Add 24-bit RGB color support
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jun  8 2017 psimons@suse.com
- Update to version 0.6.3.1.
* Wed May 31 2017 psimons@suse.com
- Update to version 0.6.3.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6.2.3 revision 0 with cabal2obs.
* Sun Sep 13 2015 mimi.vx@gmail.com
- update to 0.6.2.3
  * Add an example to the haddocks
* Sun Aug 23 2015 mimi.vx@gmail.com
- update to 0.6.2.2
  * Fix a GHC 7.10 warning
* Thu May 14 2015 mimi.vx@gmail.com
- regenerated spec with  cabal-rpm
* Sat Nov 22 2014 mimi.vx@gmail.com
- add group to devele section
* Sun Nov 16 2014 mimi.vx@gmail.com
- initial commit
